@@ -17,7 +17,7 @@ use Test::MockTime qw/restore_time set_fixed_time/;
 use App::Git::Workflow;
 use Mock::App::Git::Workflow::Repository;
 
-our $VERSION     = 0.95;
+our $VERSION     = 0.96;
 our @EXPORT      = qw/command_ok/;
 our @EXPORT_OK   = qw/command_ok/;
 our %EXPORT_TAGS = ();
@@ -72,7 +72,7 @@ sub command_ok ($$) {  ## no critic
         if ($error) {
             #die $error, $stderr if !$data->{error};
             is $error, $data->{error}, "Error matches"
-                or diag explain $error, $data->{error};
+                or ( ref $error && diag explain $error, $data->{error} );
         }
 
         # STDOUT
@@ -128,7 +128,7 @@ Test::Git::Workflow::Command - Test Git::Workflow::Command::* files
 
 =head1 VERSION
 
-This documentation refers to Test::Git::Workflow::Command version 0.95
+This documentation refers to Test::Git::Workflow::Command version 0.96
 
 =head1 SYNOPSIS
 
